@@ -8,25 +8,14 @@ raven.contrib.django.handlers
 
 from __future__ import absolute_import
 
-import logging
+from raven.contrib.django.models import client
 from raven.handlers.logging import SentryHandler as BaseSentryHandler
 
 
 class SentryHandler(BaseSentryHandler):
-    def __init__(self):
-        logging.Handler.__init__(self)
-
-    def _get_client(self):
-        from raven.contrib.django.models import client
-
-        return client
-
-    client = property(_get_client)
+    def __init__(self, *args, **kwargs):
+        super(SentryHandler, self).__init__(client=client, *args, **kwargs)
 
     def _emit(self, record):
-        from raven.contrib.django.middleware import SentryLogMiddleware
-
-        # Fetch the request from a threadlocal variable, if available
-        request = getattr(record, 'request', getattr(SentryLogMiddleware.thread, 'request', None))
-
+        request = getattr(record, 'request', None)
         return super(SentryHandler, self)._emit(record, request=request)
