@@ -9,8 +9,8 @@ from __future__ import absolute_import
 
 import re
 
+from raven._compat import string_types, text_type
 from raven.utils import varmap
-from raven.utils import six
 
 
 class Processor(object):
@@ -88,13 +88,13 @@ class SanitizePasswordsProcessor(Processor):
         if value is None:
             return
 
-        if isinstance(value, six.string_types) and self.VALUES_RE.match(value):
+        if isinstance(value, string_types) and self.VALUES_RE.match(value):
             return self.MASK
 
         if not key:  # key can be a NoneType
             return value
 
-        key = six.text_type(key).lower()
+        key = text_type(key).lower()
         for field in self.FIELDS:
             if field in key:
                 # store mask as a fixed length for security
@@ -112,7 +112,7 @@ class SanitizePasswordsProcessor(Processor):
             if n not in data:
                 continue
 
-            if isinstance(data[n], six.string_types) and '=' in data[n]:
+            if isinstance(data[n], string_types) and '=' in data[n]:
                 # at this point we've assumed it's a standard HTTP query
                 # or cookie
                 if n == 'cookies':
