@@ -5,13 +5,13 @@ import inspect
 import mock
 import raven
 import time
+import six
 
 from raven.base import Client, ClientState
 from raven.exceptions import RateLimited
 from raven.transport import AsyncTransport
 from raven.transport.http import HTTPTransport
 from raven.utils.stacks import iter_stack_frames
-from raven.utils import six
 from raven.utils.testutils import TestCase
 
 
